package com.example.wholeestate.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.session.UserElement;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.VisitMapper;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.SysUser;
import com.example.wholeestate.model.Visit;
import com.example.wholeestate.service.IBuildingService;
import com.example.wholeestate.service.ITaCollectionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 楼盘表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-20
 */
@RestController
@RequestMapping("/")
@Api(value = "楼盘API",description = "楼盘API")
public class BuildingController extends BaseController {

    @Autowired
    private IBuildingService iBuildingService;

    @Autowired
    private ITaCollectionService iTaCollectionService;

    @Autowired
    private VisitMapper visitMapper;

    private IdGen idGen = IdGen.get();

    /**
     * 自定义方法绑定请求参数的Date类型
     *
     * @param request
     * @param binder
     * @throws Exception
     */
    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @RequestMapping(value = "/buildingSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "楼盘详情", notes = "楼盘详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "楼盘id"),
    })
    public ResponseBean buildingSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingSelectId(id);
        return responseBean;
    }
    @ApiOperation(value = "楼盘列表", notes = "楼盘列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "pageNum:分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "name",value = "name:别名"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "code",value = "code:状态")
    })
    @RequestMapping(value = "/buildinglist", method = RequestMethod.GET)
    public ResponseBean buildingList(@RequestParam("pageNum")Integer pageNum,
                                     @RequestParam("pageSize")Integer pageSize,
                                     @RequestParam(value = "name", required = false)String name,
                                     @RequestParam(value = "code", required = false)String code){
        ResponseBean  responseBean = iBuildingService.buildingList(pageNum,pageSize,name,code);
        return responseBean;
    }

    @ApiOperation(value = "楼盘修改", notes = "楼盘修改")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "buildingId:楼盘ID，buildingName:楼盘名称," +
                    "name:楼盘别名，price:价格，openingDate:开盘时间，coordinate:项目坐标，propertyType:物业类型，dynamic:最新动态，tel:电话,code:樓盤編碼,img:[]多个图片,imgType:图片类型，orderNo：排序\"")

    })
    @RequestMapping(value = "/building/update", method = RequestMethod.PUT)
    public ResponseBean buildingUpdate(@RequestBody String parameter, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingUpdate(parameter);
        return responseBean;
    }

    @ApiOperation(value = "楼盘预约", notes = "楼盘预约")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageNum",value = "分页第几页" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "pageSize",value = "pageSize:每页长度" ),
            @ApiImplicitParam(paramType = "Query",dataType = "Integer",name = "buildingId",value = "buildingId:楼盘ID" ),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "username",value = "username:用户名称" ),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "phone",value = "phone:用户名称" ),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "status",value = "status:用户名称" )
    })
//    @ApiImplicitParam(paramType = "header", dataTypeClass = String.class, name = "X-Auth-Token", value = "token")
    @RequestMapping(value = "/appointmentlist", method = RequestMethod.GET)
    public ResponseBean appointmentList(@RequestParam("pageNum")Integer pageNum,
                                        @RequestParam("pageSize")Integer pageSize, HttpSession session,
                                        @RequestParam(value="buildingId",required = false)String buildingId,
                                        @RequestParam(value="username",required = false)String username,
                                        @RequestParam(value="phone",required = false)String phone,
                                        @RequestParam(value="status",required = false)String status
                                        ){
//        SysUser sessionUser= getSessionUser(session);
        ResponseBean  responseBean = iBuildingService.appointmentList(pageNum,pageSize,buildingId,username,phone,status);
        return responseBean;
    }

    @ApiOperation(value = "楼盘添加", notes = "楼盘添加")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "buildingName:楼盘名称," +
                    "name:楼盘别名，price:价格，openingDate:开盘时间，coordinate:项目坐标，propertyType:物业类型，dynamic:最新动态，tel:电话,img:[]多个图片,imgType:图片类型，orderNo：排序")

    })

    @RequestMapping(value = "/building/add", method = RequestMethod.POST)
    public ResponseBean buildingAdd(@RequestBody String parameter, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingAdd(parameter);
        return responseBean;
    }

    @ApiOperation(value = "楼盘修改成已发布", notes = "楼盘修改成已发布")
    @ApiImplicitParams({
    @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "id:楼盘id,status:状态," )

    })
    @RequestMapping(value = "/building/update/status", method = RequestMethod.PUT)
    public ResponseBean buildingUpdateStatus(@RequestBody String parameter, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingUpdateStatus(parameter);
        return responseBean;
    }

    @RequestMapping(value = "/wx/collection/{openid}", method = RequestMethod.GET)
    @ApiOperation(value = "根据 openid 查询 收藏楼盘")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行"),
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "openid", value = "openid")
    })
    public ResponseBean openidCollectionBuilding(@PathVariable("openid") String openid, @RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iTaCollectionService.openidCollectionBuilding(openid, pageNum, pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/wx/collection/{openid}", method = RequestMethod.DELETE)
    @ApiOperation(value = "微信小程序 根据 openid 和 buildingId 删除收藏楼盘")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "openid", value = "openid"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "buildingId", value = "buildingId楼盘编号"),
    })
    public ResponseBean deleteCollection(@PathVariable("openid") String openid, @RequestParam String buildingId) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iTaCollectionService.deleteCollection(openid, buildingId);
        return responseBean;
    }
    @ApiOperation(value = "楼盘删除", notes = "楼盘删除")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "parameter",value = "id:楼盘id" )

    })
    @RequestMapping(value = "/building/delete/{id}", method = RequestMethod.DELETE)
    public ResponseBean buildingdelete(@PathVariable("id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingdelete(id);
        return responseBean;
    }

    @RequestMapping(value = "/wx/collection/{openid}", method = RequestMethod.POST)
    @ApiOperation(value = "微信小程序 根据 openid 和 buildingId 收藏楼盘")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "openid", value = "openid"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "buildingId", value = "buildingId楼盘编号"),
    })
    public ResponseBean addCollection(@PathVariable("openid") String openid, @RequestParam String buildingId) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iTaCollectionService.addCollection(openid, buildingId);
        return responseBean;
    }

    @ApiOperation(value = "楼盘户型添加", notes = "楼盘户型添加")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "buildingId:楼盘id,apartmentName:户型名称，remark:备注，img:[]多个")

    })

    @RequestMapping(value = "/buildingApartment/add", method = RequestMethod.POST)
    public ResponseBean buildingApartment(@RequestBody String parameter, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingApartmentAdd(parameter);
        return responseBean;
    }

    @ApiOperation(value = "楼盘户型编辑", notes = "楼盘户型编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "apartmentId：户型ID，buildingId:楼盘id,apartmentName:户型名称，remark:备注，img:[]多个")

    })

    @RequestMapping(value = "/buildingApartment/update", method = RequestMethod.PUT)
    public ResponseBean buildingApartmentUpdate(@RequestBody String parameter){
        ResponseBean  responseBean = iBuildingService.buildingApartmentUpdate(parameter);
        return responseBean;
    }

    @RequestMapping(value = "/buildingApartment/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "楼盘户型详情", notes = "楼盘户型详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "楼盘id"),
    })
    public ResponseBean buildingApartmentSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingService.buildingApartmentSelectId(id);
        return responseBean;
    }

    @ApiOperation(value = "核销备注", notes = "核销备注")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "id", value = "核销id"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "writeoffRemark", value = "核销备注")

    })
    @RequestMapping(value = "/appointment/writeoff/{id}", method = RequestMethod.PUT)
    public ResponseBean appointmentUpdate(@PathVariable(value = "id") String id,
                                        @RequestParam(value="writeoffRemark",required = false)String writeoffRemark){
        ResponseBean  responseBean = iBuildingService.appointmentUpdate(id,writeoffRemark);
        return responseBean;
    }

   @ApiOperation(value = "户型列表根据楼盘ID查询", notes = "户型列表根据楼盘ID查询")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "id", value = "楼盘id"),
    })
    @RequestMapping(value = "/buildingApartment/buildingId/{id}", method = RequestMethod.GET)
    public ResponseBean buildingApartmentBuildingId(@PathVariable(value = "id") String id){
        ResponseBean  responseBean = iBuildingService.buildingApartmentBuildingId(id);
       return responseBean;
   }


    @ApiOperation(value = "微信小程序楼盘列表", notes = "微信小程序楼盘列表")
    @ApiImplicitParams({

    })
    @RequestMapping(value = "/wx/building/list", method = RequestMethod.GET)
    public ResponseBean getWxBuildingList(){
        ResponseBean  responseBean = iBuildingService.getWxBuildingList();
        return responseBean;
    }

    @ApiOperation(value = "微信小程序推荐楼盘列表", notes = "微信小程序推荐楼盘列表")
    @ApiImplicitParams({

    })
    @RequestMapping(value = "/wx/building/mian", method = RequestMethod.GET)
    public ResponseBean getWxMainBuildingList(){
        ResponseBean  responseBean = iBuildingService.getWxMainBuildingList();
        return responseBean;
    }

    @ApiOperation(value = "户型删除", notes = "户型删除")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "id", value = "户型id")

    })
    @RequestMapping(value = "/apartment/deleted/{id}", method = RequestMethod.DELETE)
    public ResponseBean apartmentDeleted(@PathVariable(value = "id") String id){

        ResponseBean  responseBean = iBuildingService.apartmentDel(id);
        return responseBean;
    }


    @RequestMapping(value = "/wx/buildingSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "楼盘详情", notes = "楼盘详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "楼盘id"),
    })
    public ResponseBean wxBuildingSelectId(@PathVariable(value = "id") String id){
        ResponseBean  responseBean = iBuildingService.buildingAllSelectId(id);
        return responseBean;
    }

    @RequestMapping(value = "/wx/building/visit/{id}", method = RequestMethod.POST)
    @ApiOperation(value = "楼盘访问", notes = "楼盘访问")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=String.class, name = "id", value = "楼盘id"),
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "customerId用户id;customerName用户姓名;avatar头像;visitType访问类型;visitContent内容即id")
    })
    public ResponseBean wxBuildingVisit(@PathVariable(value = "id") String id, @RequestBody String parameter){
        Visit visit = JSONObject.parseObject(parameter, Visit.class);
        QueryWrapper<Visit> visitQueryWrapper = new QueryWrapper<>();
        visitQueryWrapper.eq("visit_type", visit.getVisitType());
        visitQueryWrapper.eq("visit_content", visit.getVisitContent());
        visitQueryWrapper.eq("customer_id", visit.getCustomerId());
        List<Visit> visitList = visitMapper.selectList(visitQueryWrapper);
        ResponseBean responseBean = new ResponseBean();
        if (visitList.size() > 0) {
            Visit updataVisit = visitList.get(0);
            updataVisit.setVisitDate(new Date());
            QueryWrapper<Visit> updateQ = new QueryWrapper<>();
            updateQ.eq("visit_id", updataVisit.getVisitId());
            visitMapper.update(updataVisit, updateQ);
        } else {
            visit.setVisitId(idGen.nextId()+"");
            visit.setVisitDate(new Date());
            visitMapper.insert(visit);
        }
        return responseBean;
    }
}
