package com.example.wholeestate.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.Propaganda;
import com.example.wholeestate.service.IPropagandaService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-04-04
 */
@RestController
@RequestMapping("/")
public class PropagandaController extends BaseController {

    @Autowired
    private IPropagandaService iPropagandaService;
    private IdGen idGen = IdGen.get();


    @ApiOperation(value = "宣传列表", notes = "宣传列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行")
    })
    @RequestMapping(value = "/propagandaList", method = RequestMethod.GET)
    public ResponseBean propagandaList(
            @RequestParam(defaultValue = "1") Integer pageNum,
            @RequestParam(defaultValue = "10") Integer pageSize) {
        Page<Propaganda> pagePropaganda = new Page<>();
        pagePropaganda.setCurrent(pageNum);
        pagePropaganda.setSize(pageSize);
        QueryWrapper<Propaganda> propagandaQueryWrapper = new QueryWrapper<>();
        propagandaQueryWrapper.gt("status", -1);
        IPage<Propaganda> page = iPropagandaService.page(pagePropaganda, propagandaQueryWrapper);
        ResponseBean responseBean = new ResponseBean();
        responseBean.addSuccess(page);
        return responseBean;
    }

    @RequestMapping(value = "/propaganda/{propagandaId}", method = RequestMethod.GET)
    @ApiOperation(value = "宣传详情", notes = "宣传详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "propagandaId", value = "propagandaId id")
    })
    public ResponseBean getById(@PathVariable String propagandaId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<Propaganda> propagandaQueryWrapper = new QueryWrapper<>();
        propagandaQueryWrapper.eq("propaganda_id",propagandaId);
        Propaganda propaganda = iPropagandaService.getOne(propagandaQueryWrapper);
        responseBean.addSuccess(propaganda);
        return responseBean;
    }


    @RequestMapping(value = "/propaganda/add", method = RequestMethod.POST)
    @ApiOperation(value = "添加宣传", notes = "添加宣传")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "skipType跳转类型;imgUrl图片地址;skipUrl跳转地址;skipId主体id;")
    })
    public ResponseBean add(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Propaganda propaganda = JSONObject.parseObject(parameter, Propaganda.class);
        propaganda.setStatus(1);
        propaganda.setCreateDate(LocalDateTime.now());
        propaganda.setPropagandaId(idGen.nextId()+"");
        propaganda.setCreateDate(LocalDateTime.now());
        iPropagandaService.save(propaganda);
        return responseBean;
    }

    @RequestMapping(value = "/propaganda/update", method = RequestMethod.PUT)
    @ApiOperation(value = "修改宣传", notes = "修改宣传")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "activityId活动编号;title活动标题;activityDate活动时间;beginDate活动开始时间;endDate活动截止时间;maxNum人数限制;context内容;imgUrl图片地址")
    })
    public ResponseBean update(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Propaganda propaganda = JSONObject.parseObject(parameter, Propaganda.class);
        QueryWrapper<Propaganda> propagandaQueryWrapper = new QueryWrapper<>();
        propagandaQueryWrapper.eq("propaganda_id", propaganda.getPropagandaId());
        iPropagandaService.update(propaganda, propagandaQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/propaganda/delete/{propagandaId}", method = RequestMethod.DELETE)
    @ApiOperation(value = "删除宣传", notes = "删除宣传")
    public ResponseBean delete(@PathVariable String propagandaId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<Propaganda> propagandaQueryWrapper = new QueryWrapper<>();
        propagandaQueryWrapper.eq("propaganda_id", propagandaId);
        Propaganda propaganda = iPropagandaService.getOne(propagandaQueryWrapper);
        if (null == propaganda) {
            responseBean.addError("宣传不存在!");
            return responseBean;
        }
        propaganda.setStatus(-1);
        iPropagandaService.update(propaganda, propagandaQueryWrapper);
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }

    @ApiOperation(value = "微信宣传列表", notes = "宣传列表")
    @ApiImplicitParams({})
    @RequestMapping(value = "/wx/propagandaList", method = RequestMethod.GET)
    public ResponseBean propagandaWxList() {
        QueryWrapper<Propaganda> propagandaQueryWrapper = new QueryWrapper<>();
        propagandaQueryWrapper.eq("status", 1);
        List<Propaganda> propagandas = iPropagandaService.list(propagandaQueryWrapper);
        ResponseBean responseBean = new ResponseBean();
        responseBean.addSuccess(propagandas);
        return responseBean;
    }

}
